@@ -1,7 +1,7 @@
 /*
     Qalculate (GTK+ UI)
 
-    Copyright (C) 2003-2007, 2008, 2016  Hanna Knutsson (hanna.knutsson@protonmail.com)
+    Copyright (C) 2003-2007, 2008, 2016-2020  Hanna Knutsson (hanna.knutsson@protonmail.com)
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -119,6 +119,11 @@ enum {
 	SHORTCUT_TYPE_MANAGE_UNITS,
 	SHORTCUT_TYPE_MANAGE_DATA_SETS,
 	SHORTCUT_TYPE_STORE,
+	SHORTCUT_TYPE_MEMORY_CLEAR,
+	SHORTCUT_TYPE_MEMORY_RECALL,
+	SHORTCUT_TYPE_MEMORY_STORE,
+	SHORTCUT_TYPE_MEMORY_ADD,
+	SHORTCUT_TYPE_MEMORY_SUBTRACT,
 	SHORTCUT_TYPE_NEW_VARIABLE,
 	SHORTCUT_TYPE_NEW_FUNCTION,
 	SHORTCUT_TYPE_PLOT,
@@ -141,8 +146,14 @@ struct keyboard_shortcut {
 	std::string value;
 };
 
+struct custom_button {
+	int type[3];
+	std::string value[3], text;
+	custom_button() {type[0] = -1; type[1] = -1; type[2] = -1;}
+};
+
 std::string shortcut_to_text(guint key, guint state);
-const gchar *shortcut_type_text(int type);
+const gchar *shortcut_type_text(int type, bool return_null = false);
 void update_accels();
 
 DECLARE_BUILTIN_FUNCTION(AnswerFunction, 0)
@@ -326,6 +337,12 @@ void reload_history(gint from_index = -1);
 extern "C" {
 #endif
 
+void memory_recall();
+void memory_store();
+void memory_add();
+void memory_subtract();
+void memory_clear();
+
 gboolean on_math_entry_key_press_event(GtkWidget *o, GdkEventKey *event, gpointer);
 
 void hide_tooltip(GtkWidget*);
@@ -333,6 +350,13 @@ void hide_tooltip(GtkWidget*);
 void on_tShortcuts_selection_changed(GtkTreeSelection *treeselection, gpointer user_data);
 void on_tShortcutsType_selection_changed(GtkTreeSelection *treeselection, gpointer user_data);
 
+void on_tButtonsEdit_selection_changed(GtkTreeSelection *treeselection, gpointer);
+void on_tButtonsEdit_update_selection(GtkTreeSelection *treeselection, bool update_label_entry);
+void on_tButtonsEditType_selection_changed(GtkTreeSelection *treeselection, gpointer user_data);
+void on_buttonsedit_button_clicked(GtkButton *w, gpointer user_data);
+void on_buttonsedit_defaults_clicked(GtkButton *w, gpointer user_data);
+void on_buttonsedit_label_changed(GtkEditable *w, gpointer user_data);
+
 void insert_left_shift();
 void insert_right_shift();
 void insert_bitwise_and();
