@@ -134,37 +134,40 @@ enum {
 };
 
 void set_custom_buttons(void);
+void update_custom_buttons(int index = -1);
+void update_custom_buttons_edit(int index = -1, bool update_label_entry = true);
 void create_button_menus(void);
-void create_main_window (void);
-GtkWidget* get_functions_dialog (void);
-GtkWidget* get_variables_dialog (void);
-GtkWidget* get_units_dialog (void);
-GtkWidget* get_datasets_dialog (void);
-GtkWidget* get_preferences_dialog (void);
-GtkWidget* get_unit_edit_dialog (void);
-GtkWidget* get_function_edit_dialog (void);
-GtkWidget* get_simple_function_edit_dialog (void);
-GtkWidget* get_variable_edit_dialog (void);
-GtkWidget* get_unknown_edit_dialog (void);
-GtkWidget* get_matrix_edit_dialog (void);
-GtkWidget* get_matrix_dialog (void);
-GtkWidget* get_dataobject_edit_dialog (void);
-GtkWidget* get_dataset_edit_dialog (void);
-GtkWidget* get_dataproperty_edit_dialog (void);
-GtkWidget* get_names_edit_dialog (void);
-GtkWidget* get_csv_import_dialog (void);
-GtkWidget* get_csv_export_dialog (void);
-GtkWidget* get_set_base_dialog (void);
-GtkWidget* get_nbases_dialog (void);
-GtkWidget* get_percentage_dialog (void);
-GtkWidget* get_calendarconversion_dialog (void);
-GtkWidget* get_argument_rules_dialog (void);
-GtkWidget* get_decimals_dialog (void);
-GtkWidget* get_plot_dialog (void);
-GtkWidget* get_precision_dialog (void);
-GtkWidget* get_periodic_dialog (void);
-GtkWidget* get_shortcuts_dialog (void);
-GtkWidget* get_floatingpoint_dialog (void);
+void create_main_window(void);
+GtkWidget* get_functions_dialog(void);
+GtkWidget* get_variables_dialog(void);
+GtkWidget* get_units_dialog(void);
+GtkWidget* get_datasets_dialog(void);
+GtkWidget* get_preferences_dialog(void);
+GtkWidget* get_unit_edit_dialog(void);
+GtkWidget* get_function_edit_dialog(void);
+GtkWidget* get_simple_function_edit_dialog(void);
+GtkWidget* get_variable_edit_dialog(void);
+GtkWidget* get_unknown_edit_dialog(void);
+GtkWidget* get_matrix_edit_dialog(void);
+GtkWidget* get_matrix_dialog(void);
+GtkWidget* get_dataobject_edit_dialog(void);
+GtkWidget* get_dataset_edit_dialog(void);
+GtkWidget* get_dataproperty_edit_dialog(void);
+GtkWidget* get_names_edit_dialog(void);
+GtkWidget* get_csv_import_dialog(void);
+GtkWidget* get_csv_export_dialog(void);
+GtkWidget* get_set_base_dialog(void);
+GtkWidget* get_nbases_dialog(void);
+GtkWidget* get_percentage_dialog(void);
+GtkWidget* get_calendarconversion_dialog(void);
+GtkWidget* get_argument_rules_dialog(void);
+GtkWidget* get_decimals_dialog(void);
+GtkWidget* get_plot_dialog(void);
+GtkWidget* get_precision_dialog(void);
+GtkWidget* get_periodic_dialog(void);
+GtkWidget* get_shortcuts_dialog(void);
+GtkWidget* get_floatingpoint_dialog(void);
+GtkWidget* get_buttons_edit_dialog(void);
 GtkWidget* create_InfoWidget(const gchar *text);
 
 #endif /* INTERFACE_H */
